@@ -43,3 +43,6 @@ from fairies.excel_utils import (
     read_excel
 )
 
+from fairies.decorator_utils import(
+    clock
+)
